<?php

define('GALERIA_WIDGET__BLACKLIST_EXAMPLE', 'comma,separated,blacklisted,terms');
define('GALERIA_WIDGET__REST_PATH', '/rest/random-photo');

// Creating the widget
class GaleriaWidget extends WP_Widget {

    public function __construct() {

        parent::__construct(

            // Base ID of your widget
            'galeria_widget',

            // Widget name will appear in UI
            __('Galeria Widget', 'galeria-widget'),

            // Widget description
            [
                'description' => __('Widget for random photos from Galeria',
                    'galeria-widget'),
            ]
       );
    }

    // Creating widget front-end
    public function widget($args, $instance) {
        $title = apply_filters('widget_title', $instance['title']);
        $galeria = $instance['galeria'];
        $blacklist = $instance['blacklist'];

        // before and after widget arguments are defined by themes
        echo $args['before_widget'];
        if (! empty($title)) {
            echo $args['before_title'] . $title . $args['after_title'];
        }

        // This is where you run the code and display the output
        $url = $galeria . GALERIA_WIDGET__REST_PATH;
        if (! empty($blacklist)) {
            $url = $url . '?blacklist=' . urlencode($blacklist);
        }
        if (filter_var($url, FILTER_VALIDATE_URL)) {
            $json = file_get_contents($url);
            $g = json_decode($json);
            $response  = $g->response;
            if ($response === "success") {
                $class = $g->class;
                $image = $g->image;
                $link  = $g->link;
                $title = $g->title;
                ?>
                <div class="<?php echo $class ?>">
                    <a href="<?php echo $link ?>">
                    <img src="<?php echo $image ?>"
                         alt="<?php echo $title ?>"
                         title="<?php echo $title ?>"/></a>
                    <div class="caption"><?php echo $title ?></div>
                </div>
                <?php
            } else {
                ?><p><?php echo __('There are no pictures in the gallery.', 'galeria-widget'); ?></p><?php
            }
        } else {
            ?><p><?php echo __('Invalid URL: ', 'galeria-widget') . $url; ?></p><?php
        }

        echo $args['after_widget'];
    }

    // Widget Settings Form
    public function form($instance) {
        if (isset($instance['title'])) {
            $title = $instance['title'];
        } else {
            $title = __('New title', 'textdomain');
        }
        if (isset($instance['galeria'])) {
            $galeria = $instance['galeria'];
        } else {
            $galeria = "https://my-galeria.com";
        }
        if (isset($instance['blacklist'])) {
            $blacklist = $instance['blacklist'];
        } else {
            $blacklist = '';
        }

        // Widget admin form
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>" class="name">
                <?php _e('Title:', 'textdomain'); ?>
            </label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>"
                   name="<?php echo $this->get_field_name('title'); ?>"
                   type="text"
                   value="<?php echo esc_attr($title); ?>"
            />
            <label for="<?php echo $this->get_field_id('galeria'); ?>" class="name">
                <?php _e('Galeria URL:', 'galeria-widget'); ?>
            </label>
            <input class="widefat" id="<?php echo $this->get_field_id('galeria'); ?>"
                   name="<?php echo $this->get_field_name('galeria'); ?>"
                   type="text"
                   value="<?php echo esc_attr($galeria); ?>"
            />
            <label for="<?php echo $this->get_field_id('blacklist'); ?>" class="name">
                <?php _e('Blacklisted terms:', 'galeria-widget'); ?>
            </label>
            <input class="widefat" id="<?php echo $this->get_field_id('blacklist'); ?>"
                   name="<?php echo $this->get_field_name('blacklist'); ?>"
                   type="text"
                   value="<?php echo esc_attr($blacklist); ?>"
            />
        </p>
        <?php
    }

    // Updating widget replacing old instances with new
    public function update($new_instance, $old_instance) {
        $instance          = array();
        $instance['title'] = (! empty($new_instance['title'])) ?
            strip_tags($new_instance['title']) : '';
        $instance['galeria'] = (! empty($new_instance['galeria'])) ?
            strip_tags($new_instance['galeria']) : '';
        $instance['blacklist'] = (! empty($new_instance['blacklist'])) ?
            strip_tags($new_instance['blacklist']) : '';
        return $instance;
    }

    // Class GaleriaWidget ends here
}

// Register and load the widget
function galeria_load_widget() {
    register_widget('GaleriaWidget');
}

add_action('widgets_init', 'galeria_load_widget');
